;/*
; *****************************************************************************
; * Copyright by ScioSense B.V.                                               *
; * All rights are reserved.                                                  *
; *                                                                           *
; * IMPORTANT - PLEASE READ CAREFULLY BEFORE COPYING, INSTALLING OR USING     *
; * THE SOFTWARE.                                                             *
; *                                                                           *
; * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
; * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT         *
; * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS         *
; * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT  *
; * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,     *
; * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT          *
; * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,     *
; * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY     *
; * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT       *
; * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE     *
; * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      *
; *****************************************************************************
; */

;---- File    	: AS6031_AS6040_A1.C1.00.04.asm
;---- Created 	: 2016/06/21
;---- last change: 2020/09/02
;---- Authors	: ScioSense Support Team
;---- Company  	: ScioSense B.V., ams sensors Germany gmbh 
;---- Project  	: Assembler Template File for Customers
;----
;---- Contents 	: Firmware entry when a post processing is requested. 
;----			  The user can add his own assembler code in this file.
;----			  
;
;================================== Info about file headers ==================================
; The file headers contain a short description in and output.
; "(total) unused" refers to registers X,Y,Z and R and includes all internal subroutine calls - meaning the register is unchanged and never used in the whole process until jsubret.
; Temporary RAM are RAM cells which are used and changed, but need no initialisation and need not be kept after the call
; Permanent RAM are RAM and FWD cells which either need to be initialized and/or contain results for further processing after jsubret
; 	Note that some routines use relative addresses, such that the permanent RAM address depends on the input parameter.
;	Note: RAM used in subroutines is not listed here; note also that permanent RAM in a subroutine may be only temporary for the calling routine.
; Routines used summarizes calls within the routine, but calls in subroutines are not listed here
;=============================================================================================

#include "AS6031_AS6040_REG_A1.h"				; Header file containing definition of Register addresses, bit positions and register actions of AS6031/AS6040
#include "AS6031_AS6040_ROM_A1_common.h"		; Header file containing ROM routine start addresses - commons		
#include "AS6031_AS6040_User_FW.h"				; User Header file containing definition of User Variables, bit numbers and constants 

CONST FW_ROMVERSION_REV			0xA1			; The user can create here his own revision number. It is stored at the beginning of the program memory.
CONST FW_VERSION_NUM			0xC10000		; 
CONST FW_VERSION_MAJ			0x000000		; 
CONST FW_VERSION_MIN			0x000000		; 
CONST FW_VERSION_BLD			0x000001		; 
CONST FW_VERSION				FW_VERSION_NUM + FW_VERSION_MAJ + FW_VERSION_MIN + FW_VERSION_BLD  ;

;######################################## Start of user code with firmware code user (FWCU) revision number
; Important: Leave the following 5 lines unchanged !
	org 0						; only as information for ScioSense compiler
	nop							; only as information for ScioSense compiler
	org 32						; Address for User Code Version number
 	equal1	FW_ROMVERSION_REV	;
	equal	FW_VERSION			; Defined at the beginning of this file
	org 36						

;######################################## Start of User Code 
MK_USER_FW:
ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_PP_F, 1		;-- Check Firmware PP-F Flag
	goto 		MK_PP_F			;-- Jump to Postprocessing F

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_PP_T, 1		;-- Check Firmware PP-T Flag
	goto 		MK_PP_T			;-- Jump to Postprocessing T

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_GPH, 1		;-- Check Firmware General Purpose Handling Flag
	goto 		MK_GPH			;-- Jump to General Purpose Handling

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_FWI, 1		;-- Check Firmware Init Flag
	goto 		MK_FWI_USER		;-- Jump to Firmware Init

goto	MK_STOP


;######################################## Post Processing F (after flow and amplitude measurement task)
MK_PP_F:
; place your own code here !!!!!
;ramadr	SRR_FEP_STF				
;skipBitS	r, BNR_US_TOF_UPD				; Check if TOF update ultrasonic measurement
;	goto	MK_STOP


goto	MK_STOP


;######################################## Post Processing T (after last measurement)
MK_PP_T:
; place your own code here !!!!!
;ramadr	SRR_FEP_STF				
;skipBitS	r, BNR_TM_UPD				; Check if TM update temperature measurement
;	goto	MK_STOP

goto	MK_STOP


;######################################## General Purpose Handling
MK_GPH:
; place your own code here !!!!!


goto	MK_STOP


;######################################## Firnware Init User Routines
MK_FWI_USER:
; Initialization of USM_RLS_DLY_UP and USM_RLS_DLY_DOWN registers
ramadr	0x102					; FWD cell tbd by customer
move 	x, r
ramadr	SHR_USM_RLS_DLY_U
move 	r, x
ramadr	SHR_USM_RLS_DLY_D
move	r, x
; place your own code here !!!!!
;jsub		ROM_USER_RAM_INIT			; Optional: Initialising all USER RAM cells to 0

goto	MK_STOP


;######################################## at the end of user code stop CPU command
MK_STOP:
; place your own code here !!!!!

ramadr	SHR_CPU_REQ				; CPU Requests 0x0DC
clear 	r						; clear all CPU requests

;clrwdt							; Clearing watchdog 
								; --> remove comment when watchdog is enabled 
								; Watchdog disable: FWD 0x16C: 0x48DBA399

stop							; stop CPU

; User firmware range is up to address 0xFA0 (d3999).
;###########################################################################################
;      End of user FW
;###########################################################################################
; End of File	