;/*
; *****************************************************************************
; * Copyright by ScioSense B.V.                                               *
; * All rights are reserved.                                                  *
; *                                                                           *
; * IMPORTANT - PLEASE READ CAREFULLY BEFORE COPYING, INSTALLING OR USING     *
; * THE SOFTWARE.                                                             *
; *                                                                           *
; * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
; * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT         *
; * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS         *
; * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT  *
; * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,     *
; * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT          *
; * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,     *
; * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY     *
; * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT       *
; * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE     *
; * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      *
; *****************************************************************************
; */

;---- File    	: AS6031_AS6040_A1.F1.00.04.asm
;---- Created 	: 2016/06/21
;---- last change: 2020/08/31
;---- Authors	: ScioSense Support Team
;---- Company  	: ScioSense B.V., ams sensors Germany gmbh 
;---- Project  	: Demo simple DIF over PI (Pulse Interface)
;----
;---- Contents 	: Firmware entry when a post processing is requested. 
;----			  The user can add his own assembler code in this file.
;----			  
;
;================================== Info about file headers ==================================
; The file headers contain a short description in and output.
; "(total) unused" refers to registers X,Y,Z and R and includes all internal subroutine calls - meaning the register is unchanged and never used in the whole process until jsubret.
; Temporary RAM are RAM cells which are used and changed, but need no initialisation and need not be kept after the call
; Permanent RAM are RAM and FWD cells which either need to be initialized and/or contain results for further processing after jsubret
; 	Note that some routines use relative addresses, such that the permanent RAM address depends on the input parameter.
;	Note: RAM used in subroutines is not listed here; note also that permanent RAM in a subroutine may be only temporary for the calling routine.
; Routines used summarizes calls within the routine, but calls in subroutines are not listed here
;=============================================================================================

#include "AS6031_AS6040_REG_A1.h"				; Header file containing definition of Register addresses, bit positions and register actions of AS6031/AS6040
#include "AS6031_AS6040_ROM_A1_common.h"		; Header file containing ROM routine start addresses - commons		
#include "AS6031_AS6040_User_FW.h"				; User Header file containing definition of User Variables, bit numbers and constants 

CONST FW_ROMVERSION_REV			0xA1			; The user can create here his own revision number. It is stored at the beginning of the program memory.
CONST FW_VERSION_NUM			0xF10000		; Customer demo FW
CONST FW_VERSION_MAJ			0x000000		; 
CONST FW_VERSION_MIN			0x000000		; 
CONST FW_VERSION_BLD			0x000001		; 
CONST FW_VERSION				FW_VERSION_NUM + FW_VERSION_MAJ + FW_VERSION_MIN + FW_VERSION_BLD  ;

;######################################## Start of user code with firmware code user (FWCU) revision number
; Important: Leave the following 5 lines unchanged !
	org 0						; only as information for ScioSense compiler
	nop							; only as information for ScioSense compiler
	org 32						; Address for User Code Version number
 	equal1	FW_ROMVERSION_REV	;
	equal	FW_VERSION			; Defined at the beginning of this file
	org 36						

;######################################## Start of User Code 
MK_USER_FW:
ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_PP_F, 1		;-- Check Firmware PP-F Flag
	goto 		MK_PP_F			;-- Jump to Postprocessing F

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_PP_T, 1		;-- Check Firmware PP-T Flag
	goto 		MK_PP_T			;-- Jump to Postprocessing T

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_GPH, 1		;-- Check Firmware General Purpose Handling Flag
	goto 		MK_GPH			;-- Jump to General Purpose Handling

ramadr	SHR_CPU_REQ
skipBitC 	r, BNR_FWI, 1		;-- Check Firmware Init Flag
	goto 		MK_FWI_USER		;-- Jump to Firmware Init

goto	MK_STOP


;######################################## Post Processing F (after flow and amplitude measurement task)
MK_PP_F:
; place your own code here !!!!!
ramadr	SRR_FEP_STF				
skipBitS	r, BNR_TOF_UPD, 1			; Check if TOF update ultrasonic measurement
	goto	MK_STOP

; *** DEBUG ***
	ramadr	0x38		; delta_ToF in raw TDC values added to TOF_Sum_UP & _DOWN: Diff_ToF = 2 * delta_ToF * TOF_HIT_NO
	move 	y,r
	ramadr	0x80		; overwrite TOFSUM_UP by user entry in 0x38
;	move	r,y
;	ramadr	0x39
;	move	y,r
;	ramadr	0x84		; overwrite TOFSUM_DOWN by user entry in 0x39
;	move	r,y
	add		r, y
	ramadr	0x84
	sub		y, r		; r - y = y
	move	r, y
; *** DEBUG END ***	
	jsub 		MK_PP_DIFTOF_SCALE			;-- Jump to PP-Subroutine Flow Calculation
	ramadr 		CR_IFC_CTRL					;-- ConfigReg Pulse Interface
	skipBitC 	r, BNR_PI_EN, 1				;-- Check if Pulse Interface is enabled
		jsub 		ROM_PP_PI_UPD			;-- Jump to PP-Subroutine Pulse Interface Update	


goto	MK_STOP


;######################################## Post Processing T (after last measurement)
MK_PP_T:
; place your own code here !!!!!


goto	MK_STOP


;######################################## General Purpose Handling
MK_GPH:
; place your own code here !!!!!


goto	MK_STOP

;######################################## End of Post Processing Requests

;========================================================================================
;================================== Flow Calculation - simple scaling of DIFTOF to flow version 
;========================================================================================

MK_PP_DIFTOF_SCALE:
 ; ------------------------------------- Reading and Unifying TOF raw values-------------------------------------
	
	ramadr		FDB_US_TOF_SUM_OF_ALL_U			;---- TOF Sum Up of all the configured hits
	move		y, r
	ramadr		FDB_US_TOF_SUM_OF_ALL_D			;---- TOF Sum Down of all the configured hits
	move		z, r

	ramadr		RAM_R_TOF_HIT_NO
	move		x, r
	divmod		y, x
	ramadr		RAM_R_VA5_TOF_TO_FLT_U			; TOF sum up scaled to single TOF
	move		r, y
	move		y, z							; Z Accu : Down measurement TOF_ADD_ALL
	ramadr		RAM_R_TOF_HIT_NO
	move		x, r
	divmod		y, x
	ramadr		RAM_R_VA6_TOF_TO_FLT_D			; TOF sum down scaled to single TOF
	move		r, y

;---------------- Calculate DIFTOF: ROM_CALC_TOF_DIFF directly uses the RAM addresses from above
; This ROM routine does a simple substraction and is copied further below just for information 
; It is a simple example for a the common ROM code routine which can be used by any customer	

	;jsub		ROM_CALC_TOF_DIFF				; Calculate the DIFF TOF = TOF_UP - TOF_DOWN	
	ramadr		RAM_R_VA6_TOF_TO_FLT_D
	move		x, r
	ramadr		RAM_R_VA5_TOF_TO_FLT_U			; TOF_DIFF = TOF_TO_FLT_U - TOF_TO_FLT_D
	sub			x, r
	ramadr		RAM_R_TOF_DIFF					; Filtered Raw TOF Difference value
	move		r, x

; offset correction of TOF_DIFF
	ramadr		FWD_ZERO_OFFSET					; Zero flow offset
	move		y, r
	sub			y, x							; offset compensation: y = TOF_DIFF - zero flow offset
	move		x, y

; consider negative flow
	ramadr		FWD_NEG_TOF_DIFF_LIMIT			; Limit for negative TOF_DIFF
	getflag		r								; check if neg. limit is set
	skipEQ		3								; if no limit is set skip test for neg. limit
		compare	x, r							; check r - x
		skipNeg	1								
			move	x, r						; if TOF_DIFF neg. limit is exceeded take over neg. TOF_DIFF limit
	
; check for maximum TOF_DIFF
	ramadr		FWD_MAX_TOF_DIFF				; Maximum allowed TOF_DIFF value
	compare		x, r							; check r - x
	skipPos		1								
		move	x, r							; if negative result take over max. allowed TOF_DIFF value

; scaling DIFTOF to s with fd32	
MK_SCALE_DIFTOF:
	ramadr		RAM_R_TDC_PERIOD			; 125 or 250s * 10^-9 * 2^32
	move		y, r

	mult		y, x	
	jsub		ROM_FORMAT1_64_TO_32BIT		; Result in x with 16 integer + 16 fractional digits		
; x contains now DIFTOF in s fd 32
	move		y, 0x3B9ACA00				; scale to ns by multiplying 10^9/2^16 fd 16
	mult		y, x
	jsub		ROM_FORMAT1_64_TO_32BIT		; Result in x with 16 integer + 16 fractional digits		

; apply scaling factor; DIFTOF in ns fd 16 is still in x

	ramadr		FWD_SIMPLE_SCALE			; read scaling factor from firmware data fd16
	move		y, r
	mult		y, x
	jsub		ROM_FORMAT1_64_TO_32BIT		; Result in x with 16 integer + 16 fractional digits	
	ramadr		RAM_R_FLOW_LPH	
	move		r, x						; Flow result in Lph with 16 fd	

MK_PP_DIFTOF_SCALE_END:	
	jsubret
	

;###########################################################################################
;      End of MK_PP_DIFTOF_SCALE
;###########################################################################################	


;######################################## Firnware Init User Routines
MK_FWI_USER:
; place your own code here !!!!!
; for instance initialization of USM_RLS_DLY_UP and USM_RLS_DLY_DOWN registers
 ramadr	FWD_USM_RLS_DLY_INIT				; USM_RLS_DLY Init value
 move 		x, r
 ramadr	SHR_USM_RLS_DLY_U
 move 		r, x
 ramadr	SHR_USM_RLS_DLY_D
 move		r, x

;jsub		ROM_USER_RAM_INIT				; Initialising all USER RAM cells to 0

; defining basic parameters in RAM
	ramadr		RAM_R_TDC_CLK					; 4MHz = 0x003D0900
	move		r, 0x003D0900	
	ramadr		RAM_R_TDC_PERIOD	
	move		r, 0x431						; 250 * 10^-9 * 2^32 
	ramadr 		CR_CPM	
	skipBitC	r, BNR_HSC_DIV_MODE, 2			; Bit = 1 for 8 MHz
		ramadr	RAM_R_TDC_CLK						; 8MHz = 0x007A1200
		shiftL	r		
	ramadr 		CR_CPM		
	skipBitC	r, BNR_HSC_DIV_MODE, 2			; Bit = 1 for 8 MHz
		ramadr	RAM_R_TDC_PERIOD					; 125 * 10^-9 * 2^32 
		shiftR	r

; extract TOF_HIT_NO for calculation of TOF_SUM
	ramadr		CR_USM_TOF
	move		x, r
	and			x, 0x00001F00					; Setting mask for Bits 12:8 of CR_USM_TOF = TOF_HIT_NO	
	shiftR		x, 8							; HIT_No in lower 8 bits
	ramadr		RAM_R_TOF_HIT_NO
	move		r, x

;----- Pulse Interface initialisations -------------------------------
; Initialisations for the pulse interface, from information in the configuration registers
; Calculating TOF CYCLE TIME = (TS_CM + 1) * MR_CT * TOF_RATE
	ramadr		CR_MRG_TS		
	move		x, r
	and			x, 0x00001FFF					; X = MR_CT by masking bits 12:0 in CR_TS

	clear		y			
	or			y, 0x1F							; Masking bits 5:0
	ramadr		SHR_TOF_RATE
	move		z, r
	and			y, z							; Getting the TOF_RATE bits in Y
	mult		y, x							; Result in X, lower 17 of 32 bits
												; Result in X is TOF CYCLE TIME	
												
;				LP_MODE = 1													||			LP_MODE = 0
; MEAS_RATE		= 1024 / TOF CYCLE TIME										|| MEAS_RATE	 = 1000 / TOF CYCLE TIME
; MEAS_RATE_INV = TOF CYCLE TIME /1024										|| MEAS_RATE_INV = TOF CYCLE TIME /1000
; MEAS_RATE_INV with fd 16 = TOF CYC TIME /1024 * 2^16 = TOF CYC TIME * 2^6 || MEAS_RATE_INV with fd 16 = TOF CYC TIME /1000 * 2^16 = TOF CYC TIME * 2^6 * 1.024					
	
	shiftL		x, 6							;fd 16	
	ramadr		SRR_GPI
	skipBitS	r, BNR_LP_MODE, 3				; Skip when LP Mode
	 move		y, 0x00010624					; 1.024 * 2^16
	 mult		y, x							; Result with 32 int + 32 fd
	 jsub		ROM_FORMAT1_64_TO_32BIT			; Result in x with 16 integer + 16 fractional digits
	ramadr		RAM_R_V9E_MEAS_RATE_INV				
	move		r, x							; Inverse of the Measurement rate with 16 fd
	
; Configuring the pulse interface with the above information using ROM routine
	ramadr		FWD_R_PULSE_PER_LITER			; Getting the parameters from the firmware data memory
	move		x, r
	ramadr		FWD_R_PULSE_MAX_FLOW
	move		y, r
	ramadr		RAM_R_V9E_MEAS_RATE_INV	
	move		z, r
	
	jsub		ROM_CFG_PULSE_IF				; ROM routine to configure the pulse interface; result in X
	ramadr		RAM_R_FLOW_SCALE_FACT
	move		r, x							; fd 16


goto	MK_STOP


;######################################## at the end of user code stop CPU command
MK_STOP:
; place your own code here !!!!!

ramadr	SHR_CPU_REQ				; CPU Requests 0x0DC
clear 	r						; clear all CPU requests

;clrwdt							; Clearing watchdog --> remove comment when watchdog is enabled

stop							; stop CPU

; User firmware range is up to address 0xFA0 (d3999).
;###########################################################################################
;      End of user FW
;###########################################################################################
; End of File	