;/*
; *****************************************************************************
; * Copyright by ScioSense B.V.                                                 *
; * All rights are reserved.                                                  *
; *                                                                           *
; * IMPORTANT - PLEASE READ CAREFULLY BEFORE COPYING, INSTALLING OR USING     *
; * THE SOFTWARE.                                                             *
; *                                                                           *
; * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
; * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT         *
; * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS         *
; * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT  *
; * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,     *
; * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT          *
; * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,     *
; * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY     *
; * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT       *
; * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE     *
; * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      *
; *****************************************************************************
; */
;---- File    	   : AS6031_AS6040_REG_A1.h
;---- Date	 	   : 2020/06/04
;---- Company      : ScioSense B.V.
;---- Product      : AS6031, AS6040
;----
;---- Description  : Declarations of register addresses and bit numbers

;---- Configuration Register ----------------------------------------------

CONST CR_WD_DIS	    		0xC0			;---- Watchdog Disable											
CONST CR_IFC_CTRL	    	0xC1			;---- Pulse / EEPROM Interface
CONST CR_GP_CTRL			0xC2			;---- General purpose control
CONST CR_USM_OPT			0xC3			;---- Ultrasonic Measurement Options
CONST CR_IEH		    	0xC4			;---- Interrupt & Error Handling											
CONST CR_CPM		    	0xC5			;---- Clock & Power Management
CONST CR_MRG_TS				0xC6			;---- Measure rate generator and Task Sequencer										
CONST CR_TPM	 	    	0xC7			;---- Temperature Measurement
CONST CR_USM_PRC	    	0xC8			;---- Ultra Sonic Measurement
CONST CR_USM_FRC	    	0xC9			;---- Ultra Sonic Measurement: Fire Receive Control
CONST CR_USM_TOF	    	0xCA			;---- Ultra Sonic Measurement: Time of Flight
CONST CR_USM_AM	    		0xCB			;---- Ultra Sonic Measurement: Amplitude Measurement
CONST CR_TRIM1				0xCC			;---- Trim parameters 1; USM Tuning Parameter
CONST CR_TRIM2				0xCD			;---- Trim parameters 2; TDC Tuning Parameter
CONST CR_TRIM3				0xCE			;---- Trim parameters 3; Analog Functions Tuning Parameter
											

;---- System Handling Register ---------------------------------------------

CONST SHR_TOF_RATE    		0xD0			;---- System Handling: TOF_RATE
CONST SHR_USM_RLS_DLY_U 	0xD1 			;---- System Handling: Start Hit Delay Up
CONST SHR_USM_RLS_DLY_D 	0xD2 			;---- System Handling: Start Hit Delay Down
CONST SHR_GPO		    	0xD3			;---- System Handling: General Purpose Out
CONST SHR_PI_NPULSE   		0xD4			;---- System Handling: Pulse Interface, Number of Pulses
CONST SHR_PI_TPA   			0xD5			;---- System Handling: Pulse Interface, Distance of Pulses
CONST SHR_PI_IU_TIME 		0xD6			;---- System Handling: Pulse Interface, Auto Update Time
CONST SHR_PI_IU_NO   		0xD7			;---- System Handling: Pulse Interface, Number of Auto Updates
CONST SHR_ZCD_LVL	    	0xD9			;---- System Handling: ZCD Stored Value
CONST SHR_ZCD_FHL_U 		0xDA			;---- Zero Cross Detection, First Hit Level Up
CONST SHR_ZCD_FHL_D 		0xDB			;---- Zero Cross Detection, First Hit Level Down
CONST SHR_CPU_REQ	    	0xDC			;---- System Handling: CPU Requests
CONST SHR_EXC		    	0xDD			;---- System Handling: Execute Register
CONST SHR_RC		    	0xDE			;---- System Handling: Remote Control
CONST SHR_RC_RLS			0xDF			;---- System Handling: Remote control release							

;---- Status & Result Register ---------------------------------------------

CONST SRR_IRQ_FLAG    		0xE0			;---- Status & Result Register: IRQ Flags
CONST SRR_ERR_FLG	    	0xE1			;---- Status & Result Register: Error Flags
CONST SRR_FEP_STF	    	0xE2			;---- Status & Result Register: FEP Status Flag
CONST SRR_GPI		    	0xE3			;---- Status & Result Register: General Purpose In
CONST SRR_HCC_VAL     		0xE4			;---- Status & Result Register: HCC Value
CONST SRR_VCC_VAL	    	0xE5			;---- Status & Result Register: VCC Value
CONST SRR_TSV_HOUR	    	0xE6			;---- Status & Result Register: Time Stamp Value, Hours					
CONST SRR_TSV_MIN_SEC    	0xE7			;---- Status & Result Register: Time Stamp Value, Minutes & Seconds					
CONST SRR_TS_TIME	    	0xE9			;---- Status & Result Register: Task Sequencer Time						
CONST SRR_MSC_STF			0xEA			;---- Status & Result Register: Miscellaneous Status Flag
CONST SRR_I2C_RD			0xEB			;---- Status & Result Register: 2-wire Master Interface Read Data
CONST SRR_FWU_RNG			0xEC			;---- Status & Result Register: FW Code User Range							
CONST SRR_FWU_REV			0xED			;---- Status & Result Register: FW Code User Revision						
CONST SRR_FWA_REV			0xEE			;---- Status & Result Register: FW Code ScioSense Revision						

;================== Special Register Actions =====================================; commented unused, rest moved to SHR_RC

CONST SR_IF_CLR				0x00000001		;---- EH Clear
CONST SR_EF_CLR				0x00000002		;---- EH Clear
CONST SR_FES_CLR			0x00000004		;---- FES Clear
CONST SR_TSC_CLR			0x00000008		;---- TSC Clear
CONST SR_TSV_UPD			0x00000010		;---- TSV Update
CONST SR_PI_UPD				0x00000020		;---- PI Update
CONST SR_MCT_CLR			0x00000040		;---- MCT Clear
CONST SR_RATE_CTR_CLR		0x00000100		;---- RATE CTR Clear
; 
CONST SR_WD_DIS				0x48DBA399		;---- WD Disable

;================== Bootloader release code ===================================== 
CONST SR_FW_RLS				0xABCD7654		;---- firmware release code for boot loader

;================== Commands and bit numbers for Remote Control Request Register SHR_RC =====================================
; these commands are stored as full words since they consist of two bits - write to SHR_RC to execute
CONST SR_CFG_DONE			0x00000002		; set configuration ok after boot loading
CONST SR_RC_FLAG2			0x00000020		; set RC_FLAG2
CONST SR_RC_FLAG3			0x00002000		; set RC_FLAG3

;================== Bit Numbers of CPU Request Register SHR_CPU_REQ =====================================
CONST BNR_BLD_EXC			0 				;---- CPU request boot loader execute
CONST BNR_CHKSUM			1 				;---- Request Checksum Generation
CONST BNR_PP_T				2 				;---- Post Processing T
CONST BNR_PP_F				3 				;---- Post Processing F
CONST BNR_GPH				4 				;---- General Purpose Handling
CONST BNR_FWI				5 				;---- Request Firmware Initialization
CONST BNR_SFLAG_HSO_ST_TO	8				;---- flag indicates timeout of HSO rise time
CONST BNR_CPU_COM_REQ		9				;---- communication request (RC_COM_REQ) set by SPI interface

;================== Bit Numbers of SHR_GPO Register ===================================== 
CONST BNR_GPO0_OUT			 0  			;---- General Purpose 0 Out
CONST BNR_GPO1_OUT			 1  			;---- General Purpose 1 Out
CONST BNR_GPO2_OUT			 2 				;---- General Purpose 2 Out
CONST BNR_GPO3_OUT			 3  			;---- General Purpose 3 Out
CONST BNR_GPO4_OUT			 4  			;---- General Purpose 4 Out
CONST BNR_GPO5_OUT			 5  			;---- General Purpose 5 Out
                                                  
CONST BNR_PI_OUT_FRC0		 8 				;---- Forces Low on Pulse Output
CONST BNR_PI_OUT_FRC1		 9 				;---- Forces High on Pulse Output
CONST BNR_PI_DIR_FRC0		10 				;---- Forces Low on Pulse Direction
CONST BNR_PI_DIR_FRC1		11 				;---- Forces High on Pulse Direction
CONST BNR_FWCU_CSE			12 				;---- FWCU Checksum Error
CONST BNR_FWDU_CSE			13 				;---- FWDU Checksum Error
CONST BNR_FWCA_CSE			14 				;---- FWCA Checksum Error
CONST BNR_FWDA_CSE			15 				;---- FWDA Checksum Error

CONST BNR_FWCU_TRE			16 				;---- FWCU trim check Error
CONST BNR_FWCA_TRE			17 				;---- FWCA trim check Error
CONST BNR_FWD_TRE			18 				;---- FWD trim check Error
CONST BNR_FW_ERR			19 				;---- FW Error

;================== Bit Numbers of Execute Register SHR_EXC ==================================
CONST BNR_IF_CLR  			0 				;---- Interrupt Flag Clear
CONST BNR_EF_CLR			1 				;---- Error Flags Clear
CONST BNR_FES_CLR			2				;---- Frontend Status Clear
CONST BNR_TSC_CLR			3 				;---- Timestamp Counter Clear					
CONST BNR_TSV_UPD			4 				;---- Timestamp Value Update					
CONST BNR_PI_UPD  			5 				;---- Pulse Interface Update
CONST BNR_BG_REFRESH  		6 				;---- Bandgap Refresh
CONST BNR_MCT_CLR			7				;---- Clears measure cyle timer					
CONST BNR_RATE_CTR_CLR 		8 				;---- Clears all rate counters
CONST BNR_ZCC_RNG_CLR		9				;---- Zero Cross Calibration: Range Clear		
CONST BNR_FW_IRQ_S			10				;---- Firmware Interrupt Request, synchronized  				
CONST BNR_COM_REQ_CLR		12				;---- Communication Request Clear				
CONST BNR_GPR_REQ_CLR		13				;---- General Purpose Request Clear				
CONST BNR_GPH_TRIG			14				;---- General Purpose Trigger (via Task Seq.)	
CONST BNR_I2C_CLR			15				;---- Clears I2C interface
CONST BNR_ACP_PAGE_TGL		16				;---- Toggles ACP page
CONST BNR_HSO_REQ			17				;---- Requests high speed oscillator
CONST BNR_HSO_CLR			18				;---- Clears high speed oscillator

;================== some Bit Numbers of various Config Registers =====================================
CONST BNR_PI_EN				8 				;---- Pulse Interface Enable, register CR_IFC_CTRL          
CONST BNR_HSC_DIV			8				;---- HS_CLK_SEL, HSO is 4MHz (0) or 8MHz (1), register CR_CPM
CONST BNR_HSC_DIV_FBG		7				;---- Fire burts generator clock divider from HSC, 1 (0) or 2 (1), register CR_CPM
CONST BNR_HSC_DIV_TDC		6				;---- TDC clock divider from HSC, 1 (0) or 2 (1), register CR_CPM
CONST BNR_HSC_DIV_MODE		0				;---- mode of clock divider from HSC, common (0) or individual (1), register CR_CPM
CONST BNR_TOF_MH_IGN0		6				;---- LSB of TOF_MH_IGN in CR_USM_TOF
CONST BNR_TOF_MH_IGN1		7				;---- MSB of TOF_MH_IGN in CR_USM_TOF
CONST BNR_MH_MODE			30				;---- TOF hit output configuration in CR_USM_FRC, 0 is 3/3/4 format


; Configuration register bits for Temperature Measurement in CR_TPM 

CONST BNR_TM_PAUSE			0x00001C00		;---- for CR_TPM
CONST BNR_TM_MODE2			15				;---- Temperature Measurement Mode bit2
CONST BNR_TM_MODE1			14				;---- Temperature Measurement Mode bit1
CONST BNR_TM_MODE0			13				;---- Temperature Measurement Mode bit0

; Configuration register bits for recall timer in CR_MRG_TS

CONST BNR_TS_NVR_RATE3		23				;---- recall timer in CR_MRG_TS bit3
CONST BNR_TS_NVR_RATE2		22				;---- recall timer in CR_MRG_TS bit2
CONST BNR_TS_NVR_RATE1		21				;---- recall timer in CR_MRG_TS bit1
CONST BNR_TS_NVR_RATE0		20				;---- recall timer in CR_MRG_TS bit0
CONST BNR_TS_CST_RATE2		19				;---- checksum timer in CR_MRG_TS bit2
CONST BNR_TS_CST_RATE1		18				;---- checksum timer in CR_MRG_TS bit1
CONST BNR_TS_CST_RATE0		17				;---- checksum timer in CR_MRG_TS bit0
CONST BNR_TS_PP_F_EN		15				;---- PP_F - enable in CR_MRG_TS
CONST BNR_TS_PP_T_EN		14				;---- PP_T - enable in CR_MRG_TS
CONST BNR_TS_MCM			13				;---- Measure cycle mode setting in CR_MRG_TS (1: different phases)

;================== Bit Numbers of FEP Status Flag Register SRR_FEP_STF =====================================
CONST BNR_HCC_UPD			0 				;---- High Speed Clock Calibration Update
CONST BNR_TM_UPD			1 				;---- Temperature Update
CONST BNR_TPM_ST			3				;---- Temperature Measurement Subtask
CONST BNR_US_U_UPD			4 				;---- US Up Update
CONST BNR_US_D_UPD			5 				;---- US Down Update
CONST BNR_TOF_UPD			6 				;---- TOF Update
CONST BNR_TOF_EDGE			7				;---- TOF Measurement edge
CONST BNR_AM_UPD			8 				;---- AM Update                  
CONST BNR_AMC_UPD			9 				;---- AMC Update

;================== Bit Numbers of Interrupt Flags (SRR_IRQ_FLAG) Register ==========================
CONST BNR_ERR_FLAG			7				;---- 1 when at least one error flag is set

CONST BNR_SRR_TSQ_TMO		5				;---- Task sequencer timeout
CONST BNR_SRR_FW_IRQ_S		4				;---- Firmware Interrupt Request, synchronized with task sequencer
CONST BNR_CHKSUM_FNS		3				;---- Checksum Subroutine Finished
CONST BNR_BLD_FNS			2				;---- Bootloader Finished
CONST BNR_TSQ_FNS			0				;---- Task Sequencer Finished

;================== Bit Numbers of Error Flags (SRR_ERR_FLAG) Register ==========================
CONST BNR_CPU_ERR			15				;---- ROM operated without power
CONST BNR_NVM_FWA_ERR		14				;---- FWA checksum error
CONST BNR_NVM_FWDU_ERR		13				;---- FWDU checksum error
CONST BNR_NVM_FWCU_ERR		12				;---- FWCU checksum error
CONST BNR_CHP_ERR			11				;---- Charge pump error (AS6040 only, AS6031 not used)
CONST BNR_I2C_ACK_ERR		10				;---- I2C Acknowledge Error flag
CONST BNR_TSQ_TMO			9				;---- Task Sequencer timeout
CONST BNR_TM_SQC_TMO		8				;---- Temperature sequence timeout
CONST BNR_USM_SQC_TMO		7				;---- Ultrasonic sequence timeout
CONST BNR_LBD_ERR			6				;---- Low Battery Detect Error
CONST BNR_ZCC_ERR			5				;---- Zero Cross Calibration Error
CONST BNR_TM_SC_ERR			4				;---- Temperature Measurement Short Circuit Error
CONST BNR_TM_OC_ERR			3				;---- Temperature Measurement Open Circuit Error
CONST BNR_AM_TMO			2				;---- Amplitude Measurement Timeout
CONST BNR_TOF_TMO			1				;---- TOF Timeout
CONST BNR_TDC_TMO			0				;---- TDC Timeout

;================== Bit Numbers of General Purpose In (SRR_GPI) Register ==========================
CONST BNR_LP_MODE			8				;---- Low Power Mode
CONST BNR_GPI6_IN			6				;---- GPI 6 in
CONST BNR_GPI5_IN			5				;---- GPI 5 in
CONST BNR_GPI4_IN			4				;---- GPI 4 in
CONST BNR_GPI3_IN			3				;---- GPI 3 in
CONST BNR_GPI2_IN			2				;---- GPI 2 in
CONST BNR_GPI1_IN			1				;---- GPI 1 in
CONST BNR_GPI0_IN			0				;---- GPI 0 in

;================== Bit Numbers of Miscellaneous Status Flag Register SRR_MSC_STF =============================
CONST BNR_WD_DIS			15				;---- Watchdog Disabled
CONST BNR_E2P_BSY			14				;---- I2C busy
CONST BNR_E2P_ACK			13				;---- EEPROM Acknowledge
CONST BNR_HSO_STABLE		12				;---- Indicates HSO settling time elapsed
CONST BNR_GPR_REQ			5				;---- General purpose Request by remote interface
CONST BNR_COM_REQ			4				;---- Communication Request by remote interface


;================== RAM Frontend Data Buffer 0x80 - 0x9B 128 - 155 =============================
CONST FDB						0x80			;---- Frontend Data Buffer
	
CONST FDB_US_TOF_SUM_OF_ALL_U	0x80			;---- TOF Sum Up of all the configured hits
CONST FDB_US_PW_U				0x81			;---- US Pulse Width Ratio Up
CONST FDB_US_AM_U				0x82			;---- US Amplitude Value Up
CONST FDB_US_AMC_VH				0x83			;---- US Amplitude Calibrate Value High
CONST FDB_US_TOF_SUM_OF_ALL_D	0x84			;---- TOF Sum Down of all the configured hits
CONST FDB_US_PW_D				0x85			;---- US Pulse Width Ratio Down
CONST FDB_US_AM_D				0x86			;---- US Amplitude Value Down
CONST FDB_US_AMC_VL				0x87			;---- US Amplitude Calibrate Value Low
CONST FDB_US_TOF_0_U			0x88			;---- Ultrasonic TOF Up Value 0	
CONST FDB_US_TOF_1_U			0x89			;---- Ultrasonic TOF Up Value 1
CONST FDB_US_TOF_2_U			0x8A			;---- Ultrasonic TOF Up Value 2
CONST FDB_US_TOF_3_U			0x8B			;---- Ultrasonic TOF Up Value 3
CONST FDB_US_TOF_4_U			0x8C			;---- Ultrasonic TOF Up Value 4
CONST FDB_US_TOF_5_U			0x8D			;---- Ultrasonic TOF Up Value 5
CONST FDB_US_TOF_6_U			0x8E			;---- Ultrasonic TOF Up Value 6
CONST FDB_US_TOF_7_U			0x8F			;---- Ultrasonic TOF Up Value 7
CONST FDB_US_TOF_8_U			0x90			;---- Ultrasonic TOF Up Value 8	
CONST FDB_US_TOF_9_U			0x91			;---- Ultrasonic TOF Up Value 9
CONST FDB_US_TOF_0_D			0x92			;---- Ultrasonic TOF Down Value 0
CONST FDB_US_TOF_1_D			0x93			;---- Ultrasonic TOF Down Value 1
CONST FDB_US_TOF_2_D			0x94			;---- Ultrasonic TOF Down Value 2
CONST FDB_US_TOF_3_D			0x95			;---- Ultrasonic TOF Down Value 3
CONST FDB_US_TOF_4_D			0x96			;---- Ultrasonic TOF Down Value 4
CONST FDB_US_TOF_5_D			0x97			;---- Ultrasonic TOF Down Value 5
CONST FDB_US_TOF_6_D			0x98			;---- Ultrasonic TOF Down Value 6
CONST FDB_US_TOF_7_D			0x99			;---- Ultrasonic TOF Down Value 7
CONST FDB_US_TOF_8_D			0x9A			;---- Ultrasonic TOF Down Value 8
CONST FDB_US_TOF_9_D			0x9B			;---- Ultrasonic TOF Down Value 9

;-- Frontend Data Buffer for Temperature Measurement
CONST FDB_TPM1_M1AB_RAB_G12		0x80			;----Gain compensation
CONST FDB_TPM1_M1A_RAB_G12		0x80			;----Gain compensation
CONST FDB_TPM1_M1B_RAB_G12		0x80			;----Gain compensation
CONST FDB_TPM1_RAB_G12			0x81			;----Reference port REF-AB             
CONST FDB_TPM1_M1A_G12			0x82			;----tCAB	Temperature port M1-A       
CONST FDB_TPM1_M2A_G12			0x83			;----tHAB	Temperature port M2-A      
CONST FDB_TPM1_RA_G12			0x84			;----RDSON compensation                           	    		
CONST FDB_TPM1_MI_R_G12			0x85			;----Internal temperature reference    
CONST FDB_TPM1_MI_RM_G12		0x86			;----Internal temperature compensation 
CONST FDB_TPM1_MI_M_G12			0x87			;----Internal temperature measurement  
;CONST not used					0x88			;----
;CONST not used					0x89			;----                     	    		
;CONST not used					0x8A			;----
;CONST not used					0x8B			;----
;CONST not used					0x8C			;----
;CONST not used					0x8D			;----
CONST FDB_TPM2_M1AB_RAB_G12		0x8E			;----Gain compensation 
CONST FDB_TPM2_M1A_RAB_G12		0x8E			;----Gain compensation                   
CONST FDB_TPM2_M1B_RAB_G12		0x8E			;----Gain compensation        
CONST FDB_TPM2_RAB_G12			0x8F			;----Reference port REF-AB          
CONST FDB_TPM2_M1A_G12			0x90			;----Temperature port M1-A   
CONST FDB_TPM2_M2A_G12			0x91			;----Temperature port M2-A  
CONST FDB_TPM2_RA_G12			0x92			;----RDSON compensation                	     		
CONST FDB_TPM2_MI_R_G12			0x93 			;----Internal temperature reference    
CONST FDB_TPM2_MI_RM_G12		0x94			;----Internal temperature compensation  
CONST FDB_TPM2_MI_M_G12			0x95			;----Internal temperature measurement  
;CONST not used					0x96			;----
;CONST not used					0x97			;----
;CONST not used					0x98			;----
;CONST not used					0x99			;----
;CONST not used					0x9A			;----
;CONST not used					0x9A			;----
;CONST not used					0x9B			;----


CONST FDB_T4W1_M1AB_RAB_G12		0x80			;----Gain compensation              
CONST FDB_T4W1_RAB_G12			0x81			;----Reference port REF-AB          
CONST FDB_T4W1_M1AB_G12			0x82			;----Temperature port M1-AB         
CONST FDB_T4W1_M2AB_G12			0x83			;----Temperature port M2-AB         
CONST FDB_T4W1_RA_G12			0x84			;----Reference port REF-A                   	    		
CONST FDB_T4W1_RB_G12			0x85			;----Reference port REF-B           
CONST FDB_T4W1_M1A_G12			0x86			;----Temperature port M1-A          
CONST FDB_T4W1_M1B_G12			0x87			;----Temperature port M1-B          
CONST FDB_T4W1_M1AB_G1			0x88			;----Temperature port M1-AB         
CONST FDB_T4W1_M1AB_G2			0x89			;----Temperature port M1-AB                	    		
CONST FDB_T4W1_M2A_G12			0x8A			;----Temperature port M2-A          
CONST FDB_T4W1_M2B_G12			0x8B			;----Temperature port M2-B          
CONST FDB_T4W1_M2AB_G1			0x8C			;----Temperature port M2-AB         
CONST FDB_T4W1_M2AB_G2			0x8D			;----Temperature port M2-AB         

CONST FDB_T4W2_M1AB_RAB_G12		0x8E			;----Gain compensation              
CONST FDB_T4W2_RAB_G12			0x8F			;----Reference port REF-AB          
CONST FDB_T4W2_M1AB_G12			0x90			;----Temperature port M1-AB         
CONST FDB_T4W2_M2AB_G12			0x91			;----Temperature port M2-AB         
CONST FDB_T4W2_RA_G12			0x92			;----Reference port REF-A                          	     		
CONST FDB_T4W2_RB_G12			0x93 			;----Reference port REF-B           
CONST FDB_T4W2_M1A_G12			0x94			;----Temperature port M1-A          
CONST FDB_T4W2_M1B_G12			0x95			;----Temperature port M1-B          
CONST FDB_T4W2_M1AB_G1			0x96			;----Temperature port M1-AB         
CONST FDB_T4W2_M1AB_G2			0x97			;----Temperature port M1-AB         
CONST FDB_T4W2_M2A_G12			0x98			;----Temperature port M2-A          
CONST FDB_T4W2_M2B_G12			0x99			;----Temperature port M2-B          
CONST FDB_T4W2_M2AB_G1			0x9A			;----Temperature port M2-AB         
CONST FDB_T4W2_M2AB_G2			0x9B			;----Temperature port M2-AB         


;================== addresses that are hard coded by design, used by ROM codes =============================
CONST FWD_R_FWCU_CS					0x100			;000----Checksum Firmware Code User 
CONST FWD_R_FWDU_CS					0x101			;001----Checksum Firmware Data User

;... FWD input for configuration registers CR_... 
CONST FWD_R_CD						0x16C			;108----Configuration Data in FWD start
CONST FWD_IFC_CTRL					0x16D			;109----Configuration data for CR_GP_CTRL
CONST FWD_GP_CTRL					0x16E			;110----Configuration data for CR_GP_CTRL
CONST FWD_USM_OPT					0x16F			;111----Configuration data for CR_USM_OPT
CONST FWD_IEH						0x170			;112----Configuration data for CR_IEH
CONST FWD_CPM						0x171			;113----Configuration data for CR_CPM
CONST FWD_MRG_TS					0x172			;114----Configuration data for CR_MRG_TS 
CONST FWD_TPM						0x173			;115----Configuration data for CR_TPM 
CONST FWD_USM_PRC					0x174			;116----Configuration data for CR_USM_PRC 
CONST FWD_USM_FRC					0x175			;117----Configuration data for CR_USM_FRC 
CONST FWD_USM_TOF					0x176			;118----Configuration data for CR_USM_TOF
CONST FWD_USM_AM					0x177			;119----Configuration data for CR_USM_AM

CONST FWD_TRIM3						0x17A			;122----Configuration data for CR_TRIM3 (const value by ScioSense, not storable by user)
CONST FWD_R_LAST					0x17A			;122----Configuration Data in FWD end (unused, info only)

;-----------------------------------------------------------------------------------------------------
; End of File